# pyospackage
<!-- ALL-CONTRIBUTORS-BADGE:START - Do not remove or modify this section -->
[![All Contributors](https://img.shields.io/badge/all_contributors-1-orange.svg?style=flat-square)](#contributors-)
<!-- ALL-CONTRIBUTORS-BADGE:END -->

![PyPI - Version](https://img.shields.io/pypi/v/pyospackage)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pyospackage
)](https://pypi.org/project/pyospackage)

[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.10594121.svg)](https://doi.org/10.5281/zenodo.10594121)
[![pyOpenSci](https://tinyurl.com/y22nb8up)](https://github.com/pyOpenSci/software-review/issues/115)

## What does pyospackage do?
pyospackage is a demonstration Python package that compliments the pyOpenSci [beginner tutorial series on creating a Python package](https://www.pyopensci.org/python-package-guide/tutorials/intro.html).

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## How to install

You can install this package using either pip or conda-forge. We recommend that you create a new Python
environment to work in when installing this package. Use
whatever environment manager that you wish!

To install the package using pip:

`pip install pyospackage`

To install the package using conda-forge:

`conda install -c conda-forge pyospackage`

## Get started using packagename

To use this package:

```python
from pyospackage.add_numbers import add_num


a = add_num(1, 2)
print(a)

```

You can also add any links to this section to tutorials in your documentation.

## Development

* TODO: link to development docs when they exist and move the text below to the
docs.

### Linting & Code Formatting

TODO: this will be added to the docs once they are created in a separate pr.

All linting and code formatting is implemented in this package using a combination
of pre-commit hooks and Ruff. Ruff is a fast, rust-based linter and code
formatter that covers functionality previously implemented by Black and isort
(formatters that are commonly used in the Python ecosystem). Ruff simplifies
your linting and code format setup but running all of the checks and fixes
using a single tool. As such pyOpenSci encourages new projects to consider
using Ruff.

## Community

Information here about contributing to your package. links to your code of conduct and development guide.

## How to cite pyospackage

[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.10594121.svg)](https://doi.org/10.5281/zenodo.10594121)

To cite pyospackage please follow the citation instructions on Zenodo.

```
Leah Wasser. (2024). pyOpenSci/pyosPackage: v0.1 Test release (v0.1.0). Zenodo. https://doi.org/10.5281/zenodo.10594121
```

## License

`pyospackage` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.

## Contributors ✨

Thanks goes to these wonderful people ([emoji key](https://allcontributors.org/docs/en/emoji-key)):

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tbody>
    <tr>
      <td align="center" valign="top" width="14.28%"><a href="http://batalex.github.io"><img src="https://avatars.githubusercontent.com/u/11004857?v=4?s=100" width="100px;" alt="Alex Batisse"/><br /><sub><b>Alex Batisse</b></sub></a><br /><a href="https://github.com/pyOpenSci/pyosPackage/pulls?q=is%3Apr+reviewed-by%3ABatalex" title="Reviewed Pull Requests">👀</a></td>
    </tr>
  </tbody>
</table>

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->

This project follows the [all-contributors](https://github.com/all-contributors/all-contributors) specification. Contributions of any kind welcome!
